ValidationStatus

Enum ValidationStatus 

pub enum ValidationStatus {
    Valid,
    Stale {
        revalidate_in_background: bool,
    },
}
Whether a cached response is fresh or requires validation before or after use.

Variants



Valid

The response is fresh and can be used without any revalidation.



Stale

The response is stale.

Fields

revalidate_in_background: bool

Whether the stale response can be served immediately, leaving the caller responsible for revalidating it in the background.